@@ -1,4 +1,3 @@
-import datetime
 import uuid
 
 import django.http.request
@@ -13,6 +12,7 @@ from django.urls import path
 from django.shortcuts import render, redirect, reverse
 
 from .generator.forms import QrGenerateForm
+from .generator.qr import create_qr_code
 from .generator.zip import generate_qr_zip
 from .models import ApiHit, Department, LinkUrl, QRCode, ApiCall, Header
 from .serializers import ApiHitSerializer
@@ -48,6 +48,7 @@ class DepartmentInline(admin.TabularInline):
 
 @admin.register(User)
 class MyUserAdmin(UserAdmin):
+    # show_facets = admin.ShowFacets.NEVER
     inlines = [DepartmentInline]
 
 
@@ -56,6 +57,7 @@ class ApiHitAdmin(admin.ModelAdmin):
     readonly_fields = ('hit_date', 'action', 'code', 'message')
     list_display = ('code', 'hit_date', 'action', 'message')
     change_list_template = 'qrtoolkit_core/apihit/change_list.html'
+    # show_facets = admin.ShowFacets.NEVER
 
     # list_filter = ('code__department__name', 'code__title')
 
@@ -105,6 +107,7 @@ class QRCodeAdmin(admin.ModelAdmin):
     change_list_template = 'qrtoolkit_core/qrcode/change_list.html'
     actions = ['download_codes_action', ]
     readonly_fields = ('uuid',)
+    # show_facets = admin.ShowFacets.NEVER
 
     def get_queryset(self, request):
         qs = super(QRCodeAdmin, self).get_queryset(request)
@@ -117,7 +120,7 @@ class QRCodeAdmin(admin.ModelAdmin):
 
     def get_code_image_url(self, obj):
         return mark_safe(
-            f'<span><a href="{settings.REDIRECT_SERVICE_URL}/code/{obj.short_uuid}">/code/{obj.short_uuid}</a></span>')
+            f'<span><a href="/code/{obj.short_uuid}">/code/{obj.short_uuid}</a></span>')
 
     def get_code_url(self, obj):
         return mark_safe(
@@ -194,12 +197,21 @@ class QRCodeAdmin(admin.ModelAdmin):
                     'Content-Disposition'] = f'attachment; filename=generated_codes-{download.replace(",", "_")[:20]}.zip'
                 return resp
             else:
+                qrform = QrGenerateForm({
+                    'dark': '#000000',
+                    'light': '#FFFFFF',
+                    'scale': '3',
+                    'kind': 'svg'
+                })
+                qrform.is_valid()
+                qr_image = create_qr_code(codes.first(), qrform).decode('utf-8')
                 context = dict(
                     self.admin_site.each_context(request),
                     is_nav_sidebar_enabled=False,
                     title="Download Qr codes",
                     codes=codes,
-                    form=form
+                    form=form,
+                    qr_image=qr_image
                 )
                 return render(request, 'qrtoolkit_core/qrcode/download.html', context=context)
         else:
@@ -209,12 +221,21 @@ class QRCodeAdmin(admin.ModelAdmin):
             else:
                 codes = QRCode.objects.only('id', 'title').filter(pk__in=pks,
                                                                   department__in=request.user.departments.all()).all()
+            qrform = QrGenerateForm({
+                'dark': '#000000',
+                'light': '#FFFFFF',
+                'scale': '3',
+                'kind': 'svg'
+            })
+            qrform.is_valid()
+            qr_image = create_qr_code(codes.first(), qrform).decode('utf-8')
             context = dict(
                 self.admin_site.each_context(request),
                 is_nav_sidebar_enabled=False,
                 title="Download Qr codes",
                 codes=codes,
-                form=QrGenerateForm()
+                form=QrGenerateForm(),
+                qr_image=qr_image
             )
 
             return render(request, 'qrtoolkit_core/qrcode/download.html', context=context)
@@ -222,6 +243,7 @@ class QRCodeAdmin(admin.ModelAdmin):
 
 @admin.register(Department)
 class DepartmentAdmin(admin.ModelAdmin):
+    # show_facets = admin.ShowFacets.NEVER
     filter_horizontal = ('users',)
 
 
@@ -232,6 +254,7 @@ class HeaderInline(admin.TabularInline):
 
 @admin.register(ApiCall)
 class ApiCallAdmin(admin.ModelAdmin):
+    # show_facets = admin.ShowFacets.NEVER
     inlines = [HeaderInline]
 
     def _get_extra_context(self, request, extra_context=None):
